from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import Literal, cast






T = TypeVar("T", bound="SearchDocumentsDetail")



@_attrs_define
class SearchDocumentsDetail:
    """ Detail for a search_documents tool call.

        Attributes:
            query (str): Search query (truncated to 80 chars)
            search_mode (str): Search mode: hybrid, semantic, keyword
            tool (Literal['search_documents'] | Unset):  Default: 'search_documents'.
     """

    query: str
    search_mode: str
    tool: Literal['search_documents'] | Unset = 'search_documents'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        query = self.query

        search_mode = self.search_mode

        tool = self.tool


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "query": query,
            "search_mode": search_mode,
        })
        if tool is not UNSET:
            field_dict["tool"] = tool

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        query = d.pop("query")

        search_mode = d.pop("search_mode")

        tool = cast(Literal['search_documents'] | Unset , d.pop("tool", UNSET))
        if tool != 'search_documents'and not isinstance(tool, Unset):
            raise ValueError(f"tool must match const 'search_documents', got '{tool}'")

        search_documents_detail = cls(
            query=query,
            search_mode=search_mode,
            tool=tool,
        )


        search_documents_detail.additional_properties = d
        return search_documents_detail

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import Literal, cast






T = TypeVar("T", bound="ConnectionClosedMessage")



@_attrs_define
class ConnectionClosedMessage:
    """ Sent when connection is closed (e.g., another tab opened).

        Attributes:
            message (str):
            type_ (Literal['connection_closed'] | Unset):  Default: 'connection_closed'.
     """

    message: str
    type_: Literal['connection_closed'] | Unset = 'connection_closed'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        message = self.message

        type_ = self.type_


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "message": message,
        })
        if type_ is not UNSET:
            field_dict["type"] = type_

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        message = d.pop("message")

        type_ = cast(Literal['connection_closed'] | Unset , d.pop("type", UNSET))
        if type_ != 'connection_closed'and not isinstance(type_, Unset):
            raise ValueError(f"type must match const 'connection_closed', got '{type_}'")

        connection_closed_message = cls(
            message=message,
            type_=type_,
        )


        connection_closed_message.additional_properties = d
        return connection_closed_message

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast






T = TypeVar("T", bound="NonDeveloperConfigAgents")



@_attrs_define
class NonDeveloperConfigAgents:
    """ 
     """

    additional_properties: dict[str, bool | str] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        
        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            
            field_dict[prop_name] = prop


        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        non_developer_config_agents = cls(
        )


        additional_properties = {}
        for prop_name, prop_dict in d.items():
            def _parse_additional_property(data: object) -> bool | str:
                return cast(bool | str, data)

            additional_property = _parse_additional_property(prop_dict)

            additional_properties[prop_name] = additional_property

        non_developer_config_agents.additional_properties = additional_properties
        return non_developer_config_agents

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> bool | str:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: bool | str) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
